==> percona-server-mongodb_4.4.13.orig.tar.gz: percona-server-mongodb-4.4.13-13/src/mongo/db/auth/user_document_parser.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/status.h"
#include "mongo/db/auth/action_set.h"
#include "mongo/db/auth/user.h"
#include "mongo/db/jsobj.h"

namespace mongo {

class V2UserDocumentParser {
    V2UserDocumentParser(const V2UserDocumentParser&) = delete;
    V2UserDocumentParser& operator=(const V2UserDocumentParser&) = delete;

public:
    V2UserDocumentParser() {}
    Status checkValidUserDocument(const BSONObj& doc) const;

    /**
     * Returns Status::OK() iff the given BSONObj describes a valid element from a roles array.
     */
    static Status checkValidRoleObject(const BSONObj& roleObject);

    static Status parseRoleName(const BSONObj& roleObject, RoleName* result);

    static Status parseRoleVector(const BSONArray& rolesArray, std::vector<RoleName>* result);

    std::string extractUserNameFromUserDocument(const BSONObj& doc) const;
    User::UserId extractUserIDFromUserDocument(const BSONObj& doc) const;

    Status initializeUserCredentialsFromUserDocument(User* user, const BSONObj& privDoc) const;

    Status initializeUserRolesFromUserDocument(const BSONObj& doc, User* user) const;
    Status initializeUserIndirectRolesFromUserDocument(const BSONObj& doc, User* user) const;
    Status initializeUserPrivilegesFromUserDocument(const BSONObj& doc, User* user) const;
    Status initializeAuthenticationRestrictionsFromUserDocument(const BSONObj& doc,
                                                                User* user) const;
};

}  // namespace mongo

==> percona-server-mongodb-36_3.6.18.orig.tar.gz: percona-server-mongodb-3.6.18-5.0/src/mongo/db/auth/user_document_parser.h <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/disallow_copying.h"
#include "mongo/base/status.h"
#include "mongo/db/auth/action_set.h"
#include "mongo/db/auth/user.h"
#include "mongo/db/jsobj.h"

namespace mongo {

class V1UserDocumentParser {
    MONGO_DISALLOW_COPYING(V1UserDocumentParser);

public:
    V1UserDocumentParser() {}
    std::string extractUserNameFromUserDocument(const BSONObj& doc) const;

    Status initializeUserCredentialsFromUserDocument(User* user, const BSONObj& privDoc) const;

    Status initializeUserRolesFromUserDocument(User* user,
                                               const BSONObj& privDoc,
                                               StringData dbname) const;
};

class V2UserDocumentParser {
    MONGO_DISALLOW_COPYING(V2UserDocumentParser);

public:
    V2UserDocumentParser() {}
    Status checkValidUserDocument(const BSONObj& doc) const;

    /**
     * Returns Status::OK() iff the given BSONObj describes a valid element from a roles array.
     */
    static Status checkValidRoleObject(const BSONObj& roleObject);

    static Status parseRoleName(const BSONObj& roleObject, RoleName* result);

    static Status parseRoleVector(const BSONArray& rolesArray, std::vector<RoleName>* result);

    std::string extractUserNameFromUserDocument(const BSONObj& doc) const;
    User::UserId extractUserIDFromUserDocument(const BSONObj& doc) const;

    Status initializeUserCredentialsFromUserDocument(User* user, const BSONObj& privDoc) const;

    Status initializeUserRolesFromUserDocument(const BSONObj& doc, User* user) const;
    Status initializeUserIndirectRolesFromUserDocument(const BSONObj& doc, User* user) const;
    Status initializeUserPrivilegesFromUserDocument(const BSONObj& doc, User* user) const;
    Status initializeAuthenticationRestrictionsFromUserDocument(const BSONObj& doc,
                                                                User* user) const;
};

}  // namespace mongo
